@@ -5,7 +5,6 @@
 0xC5,0x4
 0xC6,0x4
 0xC7,0x4
-0x2D37,0x4
 0x1F54,0x4
 0x1F55,0x4
 0x1F56,0x4
@@ -72,6 +71,7 @@
 0x1F74,0x4
 0x2016,0x4
 0x2017,0x4
+0x1F75,0x4
 0x2018,0x4
 0x1F76,0x4
 0x1506,0x6
@@ -199,8 +199,8 @@
 0x1F9C,0x4
 0x20E0,0x4
 0x203F,0x4
-0x1F9D,0x4
 0x20E1,0x4
+0x1F9D,0x4
 0x1F9E,0x4
 0x20E2,0x4
 0x2040,0x4
@@ -241,6 +241,7 @@
 0x2047,0x4
 0x12FD,0x6
 0x20E9,0x4
+0x20EA,0x4
 0x2048,0x4
 0x20EB,0x4
 0x2049,0x4
@@ -284,6 +285,7 @@
 0x204E,0x4
 0x20F0,0x4
 0x20F1,0x4
+0x204F,0x4
 0x20F2,0x4
 0x2050,0x4
 0x20F3,0x4
@@ -330,10 +332,12 @@
 0x2198,0x4
 0x2199,0x4
 0x20F8,0x4
+0x219A,0x4
 0x219B,0x4
 0x20F9,0x4
 0x219C,0x4
 0x20FA,0x4
+0x2058,0x4
 0x20FB,0x4
 0x219D,0x4
 0x2059,0x4
@@ -506,6 +510,7 @@
 0x21BE,0x4
 0x21BF,0x4
 0x211D,0x4
+0x211E,0x4
 0x211F,0x4
 0x3CA,0x4
 0x3CB,0x4
@@ -571,6 +576,7 @@
 0x841,0x6
 0x3DB,0x4
 0x425,0x4
+0x4C7,0x4
 0x426,0x4
 0x4C8,0x4
 0x3DC,0x4
@@ -589,9 +595,11 @@
 0x42C,0x4
 0x42D,0x4
 0x226A,0x4
+0x226B,0x4
 0x1EF0,0x4
 0x21CA,0x4
 0x226C,0x4
+0x1EF1,0x4
 0x226D,0x4
 0x1EF2,0x4
 0x21CB,0x4
@@ -616,7 +624,6 @@
 0x2272,0x4
 0x212E,0x4
 0x212F,0x4
-0x2B09,0x4
 0x21D1,0x4
 0x1EF8,0x4
 0x2273,0x4
@@ -702,6 +709,7 @@
 0x4DB,0x4
 0x439,0x4
 0x857,0x6
+0x57E,0x4
 0x4DC,0x4
 0x43A,0x4
 0x57F,0x4
@@ -736,7 +744,6 @@
 0x1F0C,0x4
 0x21E5,0x4
 0x21E6,0x4
-0x2B1E,0x4
 0x1F0D,0x4
 0x21E7,0x4
 0x583,0x6
@@ -775,7 +782,6 @@
 0x1F14,0x4
 0x21EE,0x4
 0x1F15,0x4
-0x2B27,0x4
 0x1F16,0x4
 0x21EF,0x4
 0x1F17,0x4
@@ -827,6 +833,7 @@
 0x1F26,0x4
 0x1F27,0x4
 0x1F28,0x4
+0x1F29,0x4
 0x1F2A,0x4
 0x1F2B,0x4
 0x91C,0x6
@@ -869,11 +876,11 @@
 0x1F3B,0x4
 0x1F3C,0x4
 0x1F3D,0x4
+0x1F3E,0x4
 0x1F3F,0x4
 0x1022,0x6
 0xC08,0x6
 0xD4D,0x6
-0x2B55,0x4
 0xD56,0x6
 0xC8,0x4
 0xD6,0x4
@@ -890,7 +897,6 @@
 0xF7,0x4
 0xF8,0x4
 0xF9,0x4
-0x2CCA,0x4
 0xD85,0x6
 0x1061,0x6
 0xD8A,0x6
@@ -898,9 +904,7 @@
 0xA12,0x6
 0xFA,0x4
 0xFB,0x4
-0x2D72,0x4
 0xD8F,0x6
-0x2D7A,0x4
 0xE3B,0x6
 0x1118,0x4
 0x1119,0x4
@@ -912,8 +916,8 @@
 0x1FA5,0x4
 0x1FA6,0x4
 0x1FA7,0x4
-0x1FA8,0x4
 0x11BC,0x6
+0x1FA8,0x4
 0x1FA9,0x4
 0x1FAA,0x4
 0x111C,0x4
@@ -927,7 +931,6 @@
 0x1121,0x4
 0x1122,0x4
 0x1123,0x4
-0x1125,0x4
 0x1FAE,0x4
 0x1FAF,0x4
 0x1FB0,0x4
@@ -935,6 +938,7 @@
 0x1FB1,0x4
 0x1FB2,0x4
 0x1FB3,0x4
+0x1126,0x4
 0x1FB4,0x4
 0x1127,0x4
 0x1FB5,0x4
@@ -974,8 +978,6 @@
 0x1FC9,0x4
 0x1FCA,0x4
 0x1FCB,0x4
-0x2E4B,0x4
-0x2AD1,0x4
 0x206C,0x4
 0x206D,0x4
 0x1FCC,0x4
@@ -1010,6 +1012,7 @@
 0x329,0x4
 0x288,0x4
 0x289,0x4
+0x2076,0x4
 0x2077,0x4
 0x1FD6,0x4
 0x2078,0x4
@@ -1027,6 +1030,7 @@
 0x207F,0x4
 0x1FDD,0x4
 0x1FDE,0x4
+0x1FDF,0x4
 0x32A,0x4
 0x32B,0x4
 0x32C,0x4
@@ -1052,10 +1056,10 @@
 0x293,0x6
 0x1F2,0x4
 0x1F3,0x4
-0x1D06,0x4
 0x2081,0x4
 0x1FE0,0x4
 0x2082,0x4
+0x2083,0x4
 0x1FE1,0x4
 0x1FE2,0x4
 0x2084,0x4
@@ -1096,7 +1100,6 @@
 0x208A,0x4
 0x208B,0x4
 0x208C,0x4
-0x1D11,0x4
 0x1FEA,0x4
 0x208D,0x4
 0x1FEB,0x4
@@ -1133,6 +1136,7 @@
 0x2A5,0x6
 0x2A6,0x6
 0x2A7,0x6
+0x2134,0x4
 0x2135,0x4
 0x2136,0x4
 0x2094,0x4
@@ -1157,6 +1161,7 @@
 0x1FF9,0x4
 0x209C,0x4
 0x1FFA,0x4
+0x209D,0x4
 0x1FFB,0x4
 0x1FFC,0x4
 0x1FFD,0x4
@@ -1276,6 +1281,7 @@
 0x20B4,0x4
 0x1E7E,0x6
 0x20B5,0x4
+0x2157,0x4
 0x1E7F,0x6
 0x2158,0x4
 0x20B6,0x4
@@ -1518,8 +1524,8 @@
 0x2184,0x4
 0x2226,0x4
 0x2185,0x4
-0x1EAC,0x4
 0x2227,0x4
+0x1EAC,0x4
 0x1EAD,0x4
 0x2228,0x4
 0x2229,0x4
@@ -1574,6 +1580,7 @@
 0x2191,0x4
 0x2233,0x4
 0x1EB8,0x4
+0x2192,0x4
 0x1EB9,0x4
 0x2234,0x4
 0x2193,0x4
@@ -1637,10 +1644,12 @@
 0x542,0x4
 0x543,0x4
 0x544,0x4
+0x545,0x4
 0x2242,0x4
 0x2243,0x4
 0x1EC8,0x4
 0x1EC9,0x4
+0x2244,0x4
 0x1ECA,0x4
 0x2245,0x4
 0x2246,0x4
@@ -1673,14 +1682,15 @@
 0x54D,0x4
 0x4AC,0x4
 0x54E,0x4
+0x54F,0x4
 0x4AD,0x4
 0x4AE,0x4
 0x4AF,0x4
 0x224C,0x4
 0x224D,0x4
 0x1ED2,0x4
-0x1ED3,0x4
 0x224E,0x4
+0x1ED3,0x4
 0x1ED4,0x4
 0x224F,0x4
 0x2250,0x4
@@ -1708,7 +1718,6 @@
 0x557,0x4
 0x558,0x4
 0x559,0x4
-0x2C2F,0x4
 0x2256,0x4
 0x2257,0x4
 0x2258,0x4
@@ -1727,7 +1736,7 @@
 0x55F,0x4
 0x560,0x4
 0x562,0x4
-0x2C38,0x4
+0x563,0x4
 0x6C,0x4
 0x6D,0x4
 0x564,0x4
@@ -1778,14 +1787,12 @@
 0x85,0x4
 0x86,0x4
 0x87,0x6
-0x2C56,0x4
 0x88,0x6
 0x89,0x6
 0x8A,0x6
 0x8B,0x6
-0x2CFE,0x4
-0x2BBF,0x4
 0x1130,0x4
+0x1131,0x4
 0x1132,0x4
 0xDB7,0x6
 0x1133,0x4
@@ -1805,7 +1812,6 @@
 0x90,0x4
 0x91,0x4
 0x92,0x4
-0x2C63,0x4
 0x95,0x4
 0x113A,0x4
 0x113B,0x4
@@ -1814,7 +1820,6 @@
 0x113E,0x4
 0x113F,0x4
 0x1140,0x4
-0x1143,0x4
 0x96,0x4
 0x97,0x4
 0x98,0x4
@@ -1826,19 +1831,16 @@
 0x9E,0x6
 0x9F,0x6
 0xA52,0x6
-0x10A7,0x4
 0xA0,0x6
 0xA1,0x6
 0xA2,0x6
 0xA3,0x6
 0xA4,0x6
-0x2D14,0x4
 0xA5,0x6
 0xA6,0x6
 0xA7,0x6
 0xA8,0x4
 0xA9,0x4
-0x2C7D,0x4
 0xAA,0x4
 0xAB,0x4
 0xAC,0x4
@@ -1856,9 +1858,9 @@
 0x1F44,0x4
 0x1F45,0x4
 0x1F46,0x4
+0x1F47,0x4
 0x1F48,0x4
 0x1F49,0x4
-0x115E,0x4
 0x1F4,0x4
 0x1F5,0x4
 0x6F1,0x6
