@@ -470,6 +470,8 @@ doit(struct opt_st *opt, const char *fn, int real_argc)
   if (!mb_finfo(istream, &info_r, NULL))
     eexit(1, "%s: mb_fbind(istream, ...): %s\n", me, strerror(errno));
 
+  istream_eof = 0;
+
   if (opt->n_cs_stats) {
     mb_cs_detector_t *p = mb_falloc_cs_detector(istream, BUFSIZ, 0);
 
@@ -580,6 +582,8 @@ doit(struct opt_st *opt, const char *fn, int real_argc)
 	else if (!*line)
 	  break;
 
+	if (real_argc > 1)
+	  mb_fprintf(ostream, "%s: ", fn ? fn : "-");
 
 	if (opt->lineno)
 	  mb_fprintf(ostream, opt->format, nline, line);
